@@ -7,6 +7,8 @@ INSTALLED_APPS = [
     'lizard_map',
     'lizard_ui',
     'staticfiles',
+    'compressor',
+    'django_nose',
     'django.contrib.gis',
     'django.contrib.admin',
     'django.contrib.auth',
@@ -16,6 +18,8 @@ INSTALLED_APPS = [
     ]
 ROOT_URLCONF = 'lizard_map.urls'
 
+TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
+
 # Used for django-staticfiles
 STATIC_URL = '/static_media/'
 TEMPLATE_CONTEXT_PROCESSORS = (
