@@ -155,6 +155,8 @@ def snippet_group_graph_edit(request, snippet_group_id):
     restrict_to_month = post.get('restrict_to_month', None)
     try:
         restrict_to_month = int(restrict_to_month)
+        assert restrict_to_month > 0
+        assert restrict_to_month < 13
     except ValueError:
         restrict_to_month = None
 
